CHANGES
=======

0.3 (2012.03.16)
----------------
- add controls to limit types of changesets that get announced
  - add option to show only changesets on a certain branch
  - add option to not show single branch merges
  - add option to not show multi branch merges
  - add option to not show normal non-merge changesets

0.2.3 (2010.10.25)
------------------

- document that Campfire's API now requires HTTPS.

0.2.2 (2010.06.10)
------------------

- don't let Python 2.5 and earlier raise HTTPError on 201 response code
- list multiple changesets in most-recent-first order

0.2.1 (2010.06.08)
------------------

- don't force the message type to TextMessage

0.2.0 (2010.06.08)
------------------

- initial working version.

